@@ -60,8 +60,8 @@ def get_professional_jobs(excluded_companies: Optional[Sequence[str]] = None,
 def get_academic_jobs():
 
     courses = get_courses()
-    uf_courses = [course for course in courses if course.university == UF_NAME]
-    vcu_courses = [course for course in courses if course.university == VCU_NAME]
+    uf_courses = [course for course in courses if course.university.title == UF_NAME]
+    vcu_courses = [course for course in courses if course.university.title == VCU_NAME]
 
     return [
         AcademicEmployment(
