@@ -3,9 +3,9 @@ from typing import Optional, Sequence, Any, List
 
 import pyexlatex.resume as lr
 
-from derobertis_cv.category import CategoryModel
+from derobertis_cv.models.category import CategoryModel
 from derobertis_cv.pldata.authors import CO_AUTHORS
-from derobertis_cv.pldata.categories import CATEGORIES
+from derobertis_cv.pldata.research_categories import CATEGORIES
 from derobertis_cv.pldata.constants.authors import (
     ANDY,
     NIMAL,
