@@ -247,7 +247,7 @@ _SKILLS: List[SkillModel] = [
 
 _recursive_sort_skills(_SKILLS, key=lambda skill: skill.level, reverse=True)
 
-SKILLS: Dict[Optional[str], SkillModel] = {skill.to_lower_case_str(): skill for skill in _SKILLS}
+SKILLS: Dict[str, SkillModel] = {skill.to_lower_case_str(): skill for skill in _SKILLS}
 
 
 def get_skills(exclude_skills: Optional[Sequence[str]] = None,
