@@ -20,7 +20,7 @@ class SoftwareProject(HasLogo, pl.Template):
                  github_url: Optional[str] = None,
                  docs_url: Optional[str] = None, logo_url: Optional[str] = None,
                  package_directory: Optional[str] = None, logo_svg_text: Optional[str] = None,
-                 logo_base64: Optional[str] = None):
+                 logo_base64: Optional[str] = None, logo_fa_icon_class_str: Optional[str] = None):
         self.title = title
         self.display_title = display_title
         self.description = description
@@ -36,6 +36,7 @@ class SoftwareProject(HasLogo, pl.Template):
         self.package_directory = package_directory
         self.logo_svg_text = logo_svg_text
         self.logo_base64 = logo_base64
+        self.logo_fa_icon_class_str = logo_fa_icon_class_str
         self.contents = self._get_contents()
         super().__init__()
 
